@@ -1,20 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.2, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -46,7 +66,7 @@ XFormView::XFormView(QWidget *parent)
     pts->setPointSize(QSize(15, 15));
     pts->setShapeBrush(QBrush(QColor(151, 0, 0, alpha)));
     pts->setShapePen(QPen(QColor(255, 100, 50, alpha)));
-    pts->setConnectionPen(QPen(QColor(151, 0, 0, alpha), 0, Qt::DotLine, Qt::FlatCap, Qt::BevelJoin));
+    pts->setConnectionPen(QPen(QColor(151, 0, 0, 50)));
     pts->setBoundingRect(QRectF(0, 0, 500, 500));
     ctrlPoints << QPointF(250, 250) << QPointF(350, 250);
     pts->setPoints(ctrlPoints);
@@ -60,9 +80,10 @@ void XFormView::mousePressEvent(QMouseEvent *)
     setDescriptionEnabled(false);
 }
 
-void XFormView::resizeEvent(QResizeEvent *)
+void XFormView::resizeEvent(QResizeEvent *e)
 {
     pts->setBoundingRect(rect());
+    ArthurFrame::resizeEvent(e);
 }
 
 void XFormView::paint(QPainter *p)
@@ -133,9 +154,36 @@ void XFormView::setAnimation(bool animate)
 }
 
 void XFormView::changeRotation(int r)
+{
+    setRotation(double(r)/10.0);
+}
+
+void XFormView::changeScale(int s)
+{
+    setScale(double(s)/1000.0);
+}
+
+void XFormView::changeShear(int s)
+{
+    setShear(double(s)/1000.0);
+}
+
+void XFormView::setShear(double s)
+{
+    m_shear = s;
+    update();
+}
+
+void XFormView::setScale(double s)
+{
+    m_scale = s;
+    update();
+}
+
+void XFormView::setRotation(double r)
 {
     double old_rot = m_rotation;
-    m_rotation = double(r/10.0);
+    m_rotation = r;
 
     QPointF center(pts->points().at(0));
     QMatrix m;
@@ -147,18 +195,6 @@ void XFormView::changeRotation(int r)
     update();
 }
 
-void XFormView::changeScale(int s)
-{
-    m_scale = double(s/1000.0);
-    update();
-}
-
-void XFormView::changeShear(int s)
-{
-    m_shear = double(s/1000.0);
-    update();
-}
-
 void XFormView::timerEvent(QTimerEvent *e)
 {
     if (e->timerId() == timer.timerId()) {
@@ -210,22 +246,23 @@ void XFormView::drawPixmapType(QPainter *painter)
     painter->translate(center);
     painter->rotate(m_rotation);
     painter->scale(m_scale, m_scale);
-    painter->shear(m_shear, m_shear);
+    painter->shear(0, m_shear);
     painter->translate(-center);
 
     painter->drawPixmap(QPointF(0, 0), pixmap);
-    painter->setPen(QPen(QColor(255, 0, 0, alpha), 1, Qt::DotLine, Qt::FlatCap, Qt::BevelJoin));
+    painter->setPen(QPen(QColor(255, 0, 0, alpha), 0.25, Qt::SolidLine, Qt::FlatCap, Qt::BevelJoin));
     painter->setBrush(Qt::NoBrush);
     painter->drawRect(QRectF(0, 0, pixmap.width(), pixmap.height()).adjusted(-2, -2, 2, 2));
 }
 
 void XFormView::drawTextType(QPainter *painter)
 {
+    QPainterPath path;
     QFont f("times new roman,utopia");
     f.setStyleStrategy(QFont::ForceOutline);
     f.setPointSize(72);
     f.setStyleHint(QFont::Times);
-    painter->setFont(f);
+    path.addText(0, 0, f, textEditor->text());
 
     QFontMetrics fm(f);
     QRectF br(fm.boundingRect(textEditor->text()));
@@ -235,11 +272,12 @@ void XFormView::drawTextType(QPainter *painter)
     painter->translate(center);
     painter->rotate(m_rotation);
     painter->scale(m_scale, m_scale);
-    painter->shear(m_shear, m_shear);
+    painter->shear(0, m_shear);
     painter->translate(-center);
 
-    painter->drawText(0, 0, textEditor->text());
-    painter->setPen(QPen(QColor(255, 0, 0, alpha), 1, Qt::DotLine, Qt::FlatCap, Qt::BevelJoin));
+    painter->fillPath(path, Qt::black);
+
+    painter->setPen(QPen(QColor(255, 0, 0, alpha), 0.25, Qt::SolidLine, Qt::FlatCap, Qt::BevelJoin));
     painter->setBrush(Qt::NoBrush);
     painter->drawRect(br.adjusted(-1, -1, 1, 1));
 }
@@ -257,7 +295,7 @@ void XFormView::drawVectorType(QPainter *painter)
     painter->translate(center.x(), center.y());
     painter->rotate(m_rotation);
     painter->scale(m_scale, m_scale);
-    painter->shear(m_shear, m_shear);
+    painter->shear(0, m_shear);
     painter->translate(-center.x(), -center.y());
 
     painter->setPen(Qt::NoPen);
@@ -696,7 +734,7 @@ void XFormView::drawVectorType(QPainter *painter)
     path.closeSubpath();
     painter->drawPath(path);
 
-    painter->setPen(QPen(QColor(255, 0, 0, alpha), 1, Qt::DotLine, Qt::FlatCap, Qt::BevelJoin));
+    painter->setPen(QPen(QColor(255, 0, 0, alpha), 0.25, Qt::SolidLine, Qt::FlatCap, Qt::BevelJoin));
     painter->setBrush(Qt::NoBrush);
     painter->drawRect(br.adjusted(-1, -1, 1, 1));
 }
@@ -708,6 +746,7 @@ XFormWidget::XFormWidget(QWidget *parent)
     setWindowTitle("Affine Transformations");
 
     view = new XFormView(this);
+    view->setMinimumSize(200, 200);
 
     QGroupBox *mainGroup = new QGroupBox(this);
     mainGroup->setFixedWidth(180);
@@ -754,7 +793,14 @@ XFormWidget::XFormWidget(QWidget *parent)
 
     QPushButton *showSourceButton = new QPushButton(mainGroup);
     showSourceButton->setText("Show Source");
-
+#ifdef QT_OPENGL_SUPPORT
+    QPushButton *enableOpenGLButton = new QPushButton(mainGroup);
+    enableOpenGLButton->setText("Use OpenGL");
+    enableOpenGLButton->setCheckable(true);
+    enableOpenGLButton->setChecked(view->usesOpenGL());
+    if (!QGLFormat::hasOpenGL())
+        enableOpenGLButton->hide();
+#endif
     QPushButton *whatsThisButton = new QPushButton(mainGroup);
     whatsThisButton->setText("What's This?");
     whatsThisButton->setCheckable(true);
@@ -788,6 +834,9 @@ XFormWidget::XFormWidget(QWidget *parent)
     mainGroupLayout->addWidget(resetButton);
     mainGroupLayout->addWidget(animateButton);
     mainGroupLayout->addWidget(showSourceButton);
+#ifdef QT_OPENGL_SUPPORT
+    mainGroupLayout->addWidget(enableOpenGLButton);
+#endif
     mainGroupLayout->addWidget(whatsThisButton);
 
     connect(rotateSlider, SIGNAL(valueChanged(int)), view, SLOT(changeRotation(int)));
@@ -811,7 +860,9 @@ XFormWidget::XFormWidget(QWidget *parent)
     connect(view, SIGNAL(descriptionEnabledChanged(bool)), view->hoverPoints(), SLOT(setDisabled(bool)));
     connect(view, SIGNAL(descriptionEnabledChanged(bool)), whatsThisButton, SLOT(setChecked(bool)));
     connect(showSourceButton, SIGNAL(clicked()), view, SLOT(showSource()));
-
+#ifdef QT_OPENGL_SUPPORT
+    connect(enableOpenGLButton, SIGNAL(clicked(bool)), view, SLOT(enableOpenGL(bool)));
+#endif
     view->loadSourceFile(":res/xform.cpp");
     view->loadDescription(":res/xform.html");
 
