@@ -1,20 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.2, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -26,11 +46,10 @@
 #include "window.h"
 
 Window::Window(QWidget *parent)
-    : QWidget(parent)
+    : QDialog(parent)
 {
     browseButton = createButton(tr("&Browse..."), SLOT(browse()));
     findButton = createButton(tr("&Find"), SLOT(find()));
-    quitButton = createButton(tr("&Quit"), SLOT(close()));
 
     fileComboBox = createComboBox(tr("*"));
     textComboBox = createComboBox();
@@ -46,7 +65,6 @@ Window::Window(QWidget *parent)
     QHBoxLayout *buttonsLayout = new QHBoxLayout;
     buttonsLayout->addStretch();
     buttonsLayout->addWidget(findButton);
-    buttonsLayout->addWidget(quitButton);
 
     QGridLayout *mainLayout = new QGridLayout;
     mainLayout->addWidget(fileLabel, 0, 0);
@@ -69,8 +87,10 @@ void Window::browse()
 {
     QString directory = QFileDialog::getExistingDirectory(this,
                                tr("Find Files"), QDir::currentPath());
-    directoryComboBox->addItem(directory);
-    directoryComboBox->setCurrentIndex(directoryComboBox->currentIndex() + 1);
+    if (!directory.isEmpty()) {
+        directoryComboBox->addItem(directory);
+        directoryComboBox->setCurrentIndex(directoryComboBox->currentIndex() + 1);
+    }
 }
 
 void Window::find()
@@ -98,15 +118,15 @@ QStringList Window::findFiles(const QDir &directory, const QStringList &files,
 {
     QProgressDialog progressDialog(this);
     progressDialog.setCancelButtonText(tr("&Cancel"));
-    progressDialog.setRange(0, files.count());
+    progressDialog.setRange(0, files.size());
     progressDialog.setWindowTitle(tr("Find Files"));
 
     QStringList foundFiles;
 
-    for (int i = 0; i < files.count(); ++i) {
+    for (int i = 0; i < files.size(); ++i) {
         progressDialog.setValue(i);
         progressDialog.setLabelText(tr("Searching file number %1 of %2...")
-                              .arg(i).arg(files.count()));
+                                    .arg(i).arg(files.size()));
         qApp->processEvents();
 
         if (progressDialog.wasCanceled())
@@ -133,15 +153,15 @@ QStringList Window::findFiles(const QDir &directory, const QStringList &files,
 
 void Window::showFiles(const QDir &directory, const QStringList &files)
 {
-    for (int i = 0; i < files.count(); ++i) {
+    for (int i = 0; i < files.size(); ++i) {
         QFile file(directory.absoluteFilePath(files[i]));
         qint64 size = QFileInfo(file).size();
 
         QTableWidgetItem *fileNameItem = new QTableWidgetItem(files[i]);
         fileNameItem->setFlags(Qt::ItemIsEnabled);
-        QTableWidgetItem *sizeItem = new QTableWidgetItem(QString("%1 KB")
+        QTableWidgetItem *sizeItem = new QTableWidgetItem(tr("%1 KB")
                                              .arg(int((size + 1023) / 1024)));
-        sizeItem->setTextAlignment(Qt::AlignVCenter | Qt::AlignRight);
+        sizeItem->setTextAlignment(Qt::AlignRight | Qt::AlignVCenter);
         sizeItem->setFlags(Qt::ItemIsEnabled);
 
         int row = filesTable->rowCount();
@@ -149,7 +169,7 @@ void Window::showFiles(const QDir &directory, const QStringList &files)
         filesTable->setItem(row, 0, fileNameItem);
         filesTable->setItem(row, 1, sizeItem);
     }
-    filesFoundLabel->setText(tr("%1 file(s) found").arg(files.count()));
+    filesFoundLabel->setText(tr("%1 file(s) found").arg(files.size()));
 }
 
 QPushButton *Window::createButton(const QString &text, const char *member)
@@ -178,4 +198,3 @@ void Window::createFilesTable()
     filesTable->verticalHeader()->hide();
     filesTable->setShowGrid(false);
 }
-
