@@ -1,33 +1,53 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.2, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ****************************************************************************/
 
+#include <QtGui>
+
 #include "addtorrentdialog.h"
 #include "mainwindow.h"
 #include "ratecontroller.h"
 #include "torrentclient.h"
 
-#include <QtGui>
-
 // TorrentView extends QTreeWidget to allow drag and drop.
 class TorrentView : public QTreeWidget
 {
@@ -169,6 +189,10 @@ MainWindow::MainWindow(QWidget *parent)
             this, SLOT(pauseTorrent()));
     connect(removeTorrentAction, SIGNAL(triggered()),
             this, SLOT(removeTorrent()));
+    connect(upActionTool, SIGNAL(triggered(bool)),
+            this, SLOT(moveTorrentUp()));
+    connect(downActionTool, SIGNAL(triggered(bool)),
+            this, SLOT(moveTorrentDown()));
 
     // Load settings and start
     setWindowTitle(tr("Torrent Client"));
@@ -278,8 +302,8 @@ void MainWindow::removeTorrent()
     client->stop();
 
     // Remove the row from the view.
-    jobs.removeAt(row);
     delete torrentView->takeTopLevelItem(row);
+    jobs.removeAt(row);
     setActionsEnabled();
 
     saveChanges = true;
@@ -304,14 +328,14 @@ void MainWindow::torrentError(TorrentClient::Error)
     // Delete the client.
     TorrentClient *client = qobject_cast<TorrentClient *>(sender());
     int row = rowOfClient(client);
+    QString fileName = jobs.at(row).torrentFileName;
     jobs.removeAt(row);
 
     // Display the warning.
     QMessageBox::warning(this, tr("Error"),
                          tr("An error occurred while downloading %0: %1")
-                         .arg(jobs.at(row).torrentFileName)
-                         .arg(client->errorString()),
-                         tr("&OK"));
+                         .arg(fileName)
+                         .arg(client->errorString()));
 
     delete torrentView->takeTopLevelItem(row);
     client->deleteLater();
@@ -334,8 +358,7 @@ bool MainWindow::addTorrent(const QString &fileName, const QString &destinationF
     TorrentClient *client = new TorrentClient(this);
     if (!client->setTorrent(fileName)) {
         QMessageBox::warning(this, tr("Error"),
-                             tr("The torrent file you have selected can not be opened."),
-                             tr("&OK"));
+                             tr("The torrent file you have selected can not be opened."));
         delete client;
         return false;
     }
@@ -455,7 +478,9 @@ void MainWindow::setActionsEnabled()
 {
     // Find the view item and client for the current row, and update
     // the states of the actions.
-    QTreeWidgetItem *item = torrentView->currentItem();
+    QTreeWidgetItem *item = 0;
+    if (!torrentView->selectedItems().isEmpty())
+        item = torrentView->selectedItems().first();
     TorrentClient *client = item ? jobs.at(torrentView->indexOfTopLevelItem(item)).client : 0;
     bool pauseEnabled = client && ((client->state() == TorrentClient::Paused)
                                        ||  (client->state() > TorrentClient::Preparing));
@@ -610,7 +635,7 @@ void MainWindow::about()
 
     QDialog about(this);
     about.setModal(true);
-    about.setWindowTitle("About Torrent Client");
+    about.setWindowTitle(tr("About Torrent Client"));
     about.setLayout(mainLayout);
 
     connect(quitButton, SIGNAL(clicked()), &about, SLOT(close()));
