@@ -1,20 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.2, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -23,6 +43,7 @@
 
 #include "peerwireclient.h"
 
+#include <QHostAddress>
 #include <QTimerEvent>
 
 static const int PendingRequestTimeout = 60 * 1000;
@@ -71,6 +92,20 @@ PeerWireClient::PeerWireClient(const QByteArray &peerId, QObject *parent)
 
     connect(this, SIGNAL(readyRead()), this, SIGNAL(readyToTransfer()));
     connect(this, SIGNAL(connected()), this, SIGNAL(readyToTransfer()));
+
+    connect(&socket, SIGNAL(connected()),
+            this, SIGNAL(connected()));
+    connect(&socket, SIGNAL(readyRead()),
+            this, SIGNAL(readyRead()));
+    connect(&socket, SIGNAL(disconnected()),
+            this, SIGNAL(disconnected()));
+    connect(&socket, SIGNAL(error(QAbstractSocket::SocketError)),
+            this, SIGNAL(error(QAbstractSocket::SocketError)));
+    connect(&socket, SIGNAL(bytesWritten(qint64)),
+            this, SIGNAL(bytesWritten(qint64)));
+    connect(&socket, SIGNAL(stateChanged(QAbstractSocket::SocketState)),
+            this, SLOT(socketStateChanged(QAbstractSocket::SocketState)));
+
 }
 
 // Registers the peer ID and SHA1 sum of the torrent, and initiates
@@ -286,8 +321,8 @@ qint64 PeerWireClient::writeToSocket(qint64 bytes)
             pendingBlockSizes -= block.length;
             outgoingBuffer += block.block;
         }
-        qint64 written = QTcpSocket::writeData(outgoingBuffer.constData(),
-                                               qMin<qint64>(bytes - totalWritten, outgoingBuffer.size()));
+        qint64 written = socket.write(outgoingBuffer.constData(),
+                                      qMin<qint64>(bytes - totalWritten, outgoingBuffer.size()));
         if (written <= 0)
             return totalWritten ? totalWritten : written;
         
@@ -305,7 +340,7 @@ qint64 PeerWireClient::readFromSocket(qint64 bytes)
     char buffer[1024];
     qint64 totalRead = 0;
     do {
-        qint64 bytesRead = QTcpSocket::readData(buffer, qMin<qint64>(sizeof(buffer), bytes - totalRead));
+        qint64 bytesRead = socket.read(buffer, qMin<qint64>(sizeof(buffer), bytes - totalRead));
         if (bytesRead <= 0)
             break;
         qint64 oldSize = incomingBuffer.size();
@@ -343,18 +378,36 @@ qint64 PeerWireClient::uploadSpeed() const
     return sum / (8 * 2);
 }
 
+void PeerWireClient::setReadBufferSize(int size)
+{
+    socket.setReadBufferSize(size);
+}
+
 bool PeerWireClient::canTransferMore() const
 {
-    return !incomingBuffer.isEmpty() || QTcpSocket::bytesAvailable() > 0
+    return bytesAvailable() > 0 || socket.bytesAvailable() > 0
         || !outgoingBuffer.isEmpty() || !pendingBlocks.isEmpty();
 }
 
+void PeerWireClient::connectToHostImplementation(const QString &hostName,
+                                                 quint16 port, OpenMode openMode)
+
+{
+    setOpenMode(openMode);
+    socket.connectToHost(hostName, port, openMode);
+}
+
+void PeerWireClient::diconnectFromHostImplementation()
+{
+    socket.disconnectFromHost();
+}
+
 void PeerWireClient::timerEvent(QTimerEvent *event)
 {
     if (event->timerId() == transferSpeedTimer) {
         // Rotate the upload / download records.
         for (int i = 6; i >= 0; --i) {
-            uploadSpeedData[i + i] = uploadSpeedData[i];
+            uploadSpeedData[i + 1] = uploadSpeedData[i];
             downloadSpeedData[i + 1] = downloadSpeedData[i];
         }
         uploadSpeedData[0] = 0;
@@ -396,10 +449,9 @@ void PeerWireClient::sendHandShake()
 void PeerWireClient::processIncomingData()
 {
     invalidateTimeout = true;
-
     if (!receivedHandShake) {
         // Check that we received enough data
-        if (incomingBuffer.size() < MinimalHeaderSize)
+        if (bytesAvailable() < MinimalHeaderSize)
             return;
 
         // Sanity check the protocol ID
@@ -433,7 +485,7 @@ void PeerWireClient::processIncomingData()
 
     // Handle delayed peer id arrival
     if (!gotPeerId) {
-        if (incomingBuffer.size() < 20)
+        if (bytesAvailable() < 20)
             return;
         gotPeerId = true;
         if (read(20) == peerIdString) {
@@ -450,7 +502,7 @@ void PeerWireClient::processIncomingData()
     do {
         // Find the packet length
         if (nextPacketLength == -1) {
-            if (incomingBuffer.size() < 4)
+            if (bytesAvailable() < 4)
                 return;
 
             char tmp[4];
@@ -471,7 +523,7 @@ void PeerWireClient::processIncomingData()
         }
 
         // Wait with parsing until the whole packet has been received
-        if (incomingBuffer.size() < nextPacketLength)
+        if (bytesAvailable() < nextPacketLength)
             return;
 
         // Read the packet
@@ -508,7 +560,10 @@ void PeerWireClient::processIncomingData()
         case HavePacket: {
             // The peer has a new piece available.
             quint32 index = fromNetworkData(&packet.data()[1]);
-            peerPieces.setBit(int(index));
+            if (index < quint32(peerPieces.size())) {
+                // Only accept indexes within the valid range.
+                peerPieces.setBit(int(index));
+            }
             emit piecesAvailable(availablePieces());
             break;
         }
@@ -516,8 +571,16 @@ void PeerWireClient::processIncomingData()
             // The peer has the following pieces available.
             for (int i = 1; i < packet.size(); ++i) {
                 for (int bit = 0; bit < 8; ++bit) {
-                    if (packet.at(i) & (1 << (7 - bit)))
-                        peerPieces.setBit(int(((i - 1) * 8) + bit));
+                    if (packet.at(i) & (1 << (7 - bit))) {
+                        int bitIndex = int(((i - 1) * 8) + bit);
+                        if (bitIndex >= 0 && bitIndex < peerPieces.size()) {
+                            // Occasionally, broken clients claim to have
+                            // pieces whose index is outside the valid range.
+                            // The most common mistake is the index == size
+                            // case.
+                            peerPieces.setBit(bitIndex);
+                        }
+                    }
                 }
             }
             emit piecesAvailable(availablePieces());
@@ -567,7 +630,17 @@ void PeerWireClient::processIncomingData()
             break;
         }
         nextPacketLength = -1;
-    } while (incomingBuffer.size() > 0);
+    } while (bytesAvailable() > 0);
+}
+
+void PeerWireClient::socketStateChanged(QAbstractSocket::SocketState state)
+{
+    setLocalAddress(socket.localAddress());
+    setLocalPort(socket.localPort());
+    setPeerName(socket.peerName());
+    setPeerAddress(socket.peerAddress());
+    setPeerPort(socket.peerPort());
+    setSocketState(state);
 }
 
 qint64 PeerWireClient::readData(char *data, qint64 size)
